@@ -388,7 +388,7 @@ class SpglibSymmetryFinder:
 
         return spglib.get_spacegroup_type(
             spglib.get_symmetry_dataset(cell=cell, symprec=symprec)["hall_number"]
-        )["pointgroup_international"]
+        )["pointgroup_schoenflies"]
 
     # def get_rotations(self, pointgroup_symbol):
     #     """
